@@ -22,14 +22,22 @@
  *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
  *  02110-1301, USA.
  */
- 
- /* a convenience header for anyone working with the libcashobjects.la library. */
- 
+
+/* a convenience header for anyone working with the libcashobjects.la library. */
+
 #ifndef _CASHOBJECTS_H
 #define _CASHOBJECTS_H
 
 #include <glib.h>
 
+#ifdef __cplusplus
+extern "C" {
+#endif
+
 gboolean cashobjects_register(void);
 
+#ifdef __cplusplus
+}
+#endif
+
 #endif /* _CASHOBJECTS_H */
