@@ -29,6 +29,10 @@
 #include <gtk/gtk.h>
 #include "qof.h"
 
+#ifdef __cplusplus
+extern "C" {
+#endif
+
 #define GNC_PREF_GRID_LINES_HORIZONTAL "grid-lines-horizontal"
 #define GNC_PREF_GRID_LINES_VERTICAL   "grid-lines-vertical"
 
@@ -65,7 +69,7 @@ void gnc_save_window_size (const char *section, GtkWindow *window);
 void gnc_window_adjust_for_screen (GtkWindow * window);
 
 /********************************************************************\
- * Sets the alignament of a Label Widget, GTK3 version specific.    *
+ * Sets the alignment of a Label Widget, GTK3 version specific.    *
  *                                                                  *
  * Args: widget - the label widget to set alignment on              *
  *       xalign - x alignment                                       *
@@ -89,7 +93,6 @@ GtkTreeViewGridLines gnc_tree_view_get_grid_lines_pref (void);
  *       gnc_class - character string for css class name            *
  * Returns:  nothing                                                *
 \********************************************************************/
-void gnc_widget_set_style_context (GtkWidget *widget, const char *gnc_class);
 void gnc_widget_style_context_add_class (GtkWidget *widget, const char *gnc_class);
 
 /********************************************************************\
@@ -161,4 +164,19 @@ gboolean gnc_new_book_option_display (GtkWidget *parent);
 GtkWidget *
 gnc_cost_policy_select_new (void);
 
+/** This function returns the color string for the CSS 'gnc-class-negative-numbers' class,
+ *  the returned value must be freed.
+ */
+gchar* gnc_get_negative_color (void);
+
+
+
+/** This function sets the title of an owner dialog */
+void gnc_owner_window_set_title (GtkWindow*, const char*, GtkWidget*, GtkWidget*);
+
+
+#ifdef __cplusplus
+}
+#endif
+
 #endif /* DIALOG_UTILS_H */
