@@ -37,6 +37,10 @@
 #ifndef XACC_POLICY_H
 #define XACC_POLICY_H
 
+#ifdef __cplusplus
+extern "C" {
+#endif
+
 typedef struct gncpolicy_s GNCPolicy;
 
 /** First-in, First-out Policy
@@ -47,18 +51,13 @@ typedef struct gncpolicy_s GNCPolicy;
  *  -- Splits are added to the lot in date order, with earliest splits
  *     added first.
  *  -- All splits in the lot share the same transaction currency as
- *     the split that opened the lot.
+ *     the split that opened the lot
  */
 GNCPolicy *xaccGetFIFOPolicy (void);
 
-/** Last-in, First-out Policy
- *  This policy will create LIFO Lots.  LIFO Lots have the following
- *  properties:
- *  -- XXX  I think the implementation is broken right now.
- *  -- All splits in the lot share the same transaction currency as
- *     the split that opened the lot.
- */
-GNCPolicy *xaccGetLIFOPolicy (void);
+#ifdef __cplusplus
+} /* extern "C" */
+#endif
 
 #endif /* XACC_POLICY_H */
 /** @} */
