@@ -727,7 +727,7 @@
   (define (currency_ns? ns)
     (or (string=? (GNC-COMMODITY-NS-CURRENCY) ns)
         (string=? (GNC-COMMODITY-NS-LEGACY) ns)
-        (string=? (GNC-COMMODITY-NS-ISO4217) ns)))
+        (string=? (GNC-COMMODITY-NS-ISO) ns)))
 
   ;; Guess a namespace based on the symbol alone.
   (define (guess-by-symbol s)
@@ -741,16 +741,18 @@
                           ;; compatible with the QIF type?
                           (and (string=? s (caddr elt))
                                (not (and (string? qif-type)
-                                         (not (currency_ns? (cadr elt))
+                                         (not (currency_ns? (cadr elt)))
                                          (or (string-ci=? qif-type "stock")
                                              (string-ci=? qif-type "etf")
                                              (string-ci=? qif-type "mutual fund")
-                                             (string-ci=? qif-type "index")
-)))))
+                                             (string-ci=? qif-type "index"))))))
                         prefs)
-                   #f))))
-        ;; If a preferences match was found, use its namespace.
-        (if pref-match (cadr pref-match)))
+                   #f)))
+        ;; If a preferences match was found, use its namespace,
+        ;; otherwise the default non-currency namespace.
+        (if pref-match
+             (cadr pref-match)
+             (GNC-COMMODITY-NS-NONCURRENCY)))
       ;; There's no symbol. Use the built-in default.
       (GNC-COMMODITY-NS-NONCURRENCY)))
 
@@ -815,6 +817,7 @@
                          (set! qif-symbol security-name))
 
                      ;; Create the new security and add it to the hash table.
+
                      (hash-set! security-hash
                                 security-name
                                 (gnc-commodity-new book
